Values are stored as canonical decimal strings so values outside R's exact numeric range are not silently rounded.
Usage
rducks_hugeint(x = character())Values are stored as canonical decimal strings so values outside R's exact numeric range are not silently rounded.
rducks_hugeint(x = character())