Values are stored as canonical decimal strings so signed 64-bit values are not silently rounded through R double.
Usage
rducks_bigint(x = character())Values are stored as canonical decimal strings so signed 64-bit values are not silently rounded through R double.
rducks_bigint(x = character())