rducks_bits() stores bits as packed raw bytes plus an explicit bit length.
Bits are packed left-to-right, with the first bit in the high bit of the
first byte.
Usage
rducks_bits(x = raw(), length = NULL)
rducks_bits_raw(x)Examples
b <- rducks_bits("10110")
as.character(b)
#> [1] "10110"
rducks_bits_raw(b)
#> [1] b0